@@ -1,5 +1,7 @@
 /* We need sigaction() and struct sigaction */
-#define _POSIX_C_SOURCE 199309L
+#ifdef __GLIBC__
+#  define _POSIX_C_SOURCE 199309L
+#endif
 
 #include "tickit.h"
 #include "tickit-evloop.h"
